@@ -162,11 +162,12 @@ def contracts(
         end_year: t.Optional[int] = None,
         months: t.Optional[t.Tuple[str, ...]] = None,
         start_date: t.Optional[date] = None,
+        monthly_contracts_only:bool = True,
 ) -> pd.DataFrame:
     matched_futures = tuple(
         symbol for symbol, type in find_symbols_in_query(formula).items() if type == "FUTURES"
     )
-    contracts_list = get_symbol_contract_list(*matched_futures, monthly_contracts_only=True)
+    contracts_list = get_symbol_contract_list(*matched_futures, monthly_contracts_only=monthly_contracts_only)
     contracts_list = limutils.filter_contracts(contracts_list, start_year=start_year, end_year=end_year, months=months)
     return _contracts(formula, matches=matched_futures, contracts_list=contracts_list, start_date=start_date)
 
@@ -237,7 +238,7 @@ def relations(
     return df
 
 
-def find_symbols_in_path(path: str) -> list:
+def find_symbols_in_path(path: str, type:str=None) -> list:
     """
     Given a path in the LIM tree hierarchy, find all symbols in that path.
     """
@@ -247,11 +248,15 @@ def find_symbols_in_path(path: str) -> list:
     for col in df.columns:
         children = df[col]['children']
         for _, row in children.iterrows():
-            if row.type == 'FUTURES' or row.type == 'NORMAL':
-                symbols.append(row['name'])
-            elif row.type == 'CATEGORY':
-                rec_symbols = find_symbols_in_path(f'{path}:{row["name"]}')
-                symbols = symbols + rec_symbols
+            if type is not None:
+                if row.type == type:
+                    symbols.append(row['name'])
+            else:
+                if row.type == 'FUTURES' or row.type == 'NORMAL':
+                    symbols.append(row['name'])
+            if row.type == 'CATEGORY':
+                    rec_symbols = find_symbols_in_path(f'{path}:{row["name"]}', type=type)
+                    symbols = symbols + rec_symbols
     return symbols
 
 
@@ -287,14 +292,17 @@ def find_symbols_in_query(query: str) -> dict:
 
 
 if __name__ == '__main__':
-    q = 'Show 1: FP/7.45-FB'
-    find_symbols_in_query(q)
-    # contracts('NYMEX.CU')
-    # series('PGABM00')
-    fcurves = {
-        'FB': 'Brent',
-        'FP': 'ULSD',
-        'JKM': 'NYMEX.JKM',
-        'C3_PROPANE_CIF_ARA_LGE': 'Propane'
-    }
-    curve(fcurves)
+    # q = 'Show 1: FP/7.45-FB'
+    # find_symbols_in_query(q)
+    # # contracts('NYMEX.CU')
+    # # series('PGABM00')
+    # fcurves = {
+    #     'FB': 'Brent',
+    #     'FP': 'ULSD',
+    #     'JKM': 'NYMEX.JKM',
+    #     'C3_PROPANE_CIF_ARA_LGE': 'Propane'
+    # }
+    # curve(fcurves)
+    contracts(formula='Show 1: FP/7.45-FB', months=['F'], start_year=2020, start_date='2020-01-01')
+
+
